@@ -859,9 +859,7 @@ class frmViewWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), self.DeleteLogFile)
         QtCore.QObject.connect(self.ui.bOpen, QtCore.SIGNAL("clicked()"), self.OpenRecord)
         QtCore.QObject.connect(self.ui.bOpenDate, QtCore.SIGNAL("clicked()"), self.OpenDate)
-        QtCore.QObject.connect(self.ui.bEditNote, QtCore.SIGNAL("clicked()"), self.EditNote)
-#        QtCore.QObject.connect(self.ui.bLeft, QtCore.SIGNAL("clicked()"), self.goLeft)
-#        QtCore.QObject.connect(self.ui.bRight, QtCore.SIGNAL("clicked()"), self.goRight)
+        QtCore.QObject.connect(self.ui.bStatistics, QtCore.SIGNAL("clicked()"), self.ShowRecordData)
 
         QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL("triggered()"), self.About)
         QtCore.QObject.connect(self.ui.actionShowRecordData, QtCore.SIGNAL("triggered()"), self.ShowRecordData)
@@ -879,8 +877,7 @@ class frmViewWindow(QMainWindow):
         self.ui.bOpen.setStyleSheet(data.UIStyle)
         self.ui.bOpenDate.setStyleSheet(data.UIStyle)
         self.ui.bEditNote.setStyleSheet(data.UIStyle)
-#        self.ui.bLeft.setStyleSheet(data.UIStyle)
-#        self.ui.bRight.setStyleSheet(data.UIStyle)
+        self.ui.bStatistics.setStyleSheet(data.UIStyle)
         
         
         
@@ -895,9 +892,8 @@ class frmViewWindow(QMainWindow):
             self.ui.bZoomOut.setIcon(QIcon(data.app_path+"img/"+"zoom-out.png"))
             self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"img/"+"go-up.png"))
             self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"img/"+"go-down.png"))
-#            self.ui.bLeft.setIcon(QIcon(data.app_path+"img/"+"go-previous.png"))
-#            self.ui.bRight.setIcon(QIcon(data.app_path+"img/"+"go-next.png"))
             self.ui.bEditNote.setIcon(QIcon(data.app_path+"img/"+"kwrite.png"))
+            self.ui.bStatistics.setIcon(QIcon(data.app_path+"img/"+"klipper_dock.png"))
 
 
 
@@ -1873,6 +1869,7 @@ class MyGraphCanvas(QtGui.QWidget):
 
         paint = QtGui.QPainter()
         paint.begin(self)        
+#        paint.setBackgroundMode(QtCore.Qt.TransparentMode)
         paint.drawPixmap(0, 0, data.GraphBitMap) #load graph from Bitmap
         paint.end()
 
@@ -1888,7 +1885,7 @@ class MyGraphCanvas(QtGui.QWidget):
 class MyStatCanvas(QtGui.QWidget):
     def __init__(self, parent):
         QMainWindow.__init__(self, parent)    
-        self.setGeometry(402, 280, data.StatisticsBitMapLen,  data.StatisticsBitMapHeight)
+        self.setGeometry(406, 280, data.StatisticsBitMapLen,  data.StatisticsBitMapHeight)
         
 
     ###########################################################################
@@ -1903,6 +1900,7 @@ class MyStatCanvas(QtGui.QWidget):
 
         paint = QtGui.QPainter()
         paint.begin(self)        
+        paint.setBackgroundMode(QtCore.Qt.TransparentMode)
         paint.drawPixmap(0, 0, data.StatisticsBitMap) #load statistics from Bitmap
         paint.end()
 
